from datetime import datetime
from typing import List, Optional, Dict, Any

from janis_core import *
from janis_core.types.common_data_types import Int, Float, File, String

Kmerfreq_Ar_V0_1_0 = CommandToolBuilder(tool="KmerFreq_AR", base_command=["KmerFreq_AR"], inputs=[ToolInput(tag="in_set_kmer_size", input_type=Int(optional=True), prefix="-k", doc=InputDocumentation(doc="Set the kmer size, default=17.\nNote: when k=17, kmer theoretic number is 4^17 = 16G,\nstore 1 byte for a kmer, the kmer frequency spectrum will use\n16G memory(k=16, 4G; k=18, 64G).")), ToolInput(tag="in_set_size_defaultnote", input_type=Int(optional=True), prefix="-s", doc=InputDocumentation(doc="Set the size of space-seed in kmer, default=0.\nNote: for consecutive kmer, use default value: 0; for space-kmer, set this\noption and make sure it is set to be one even number when kmer size is\nodd number(for reverse and complement kmer). When kmer size is one even number,\nthe space-kmer format will be like this(for k=10, s=5): 'ATTCG-----GTACG'.\nWhen kmer size is odd number, the space-kmer format will be like this(for k=11, s=4):\n'ATTCG--A--GTACG'.")), ToolInput(tag="in_set_min_precision", input_type=Float(optional=True), prefix="-c", doc=InputDocumentation(doc="Set min precision rate for kmer, default=-1.\nNote: program caculate the precision of kmer base on the quality score,\nset between 0~0.99, or -1 for unrestrained.")), ToolInput(tag="in_set_thread_number", input_type=Int(optional=True), prefix="-t", doc=InputDocumentation(doc="Set the thread number, default=1.\nNote: the more thread number, the high speed, however, this should be less than\nthe number of CPU cores.")), ToolInput(tag="in_set_ascii_shift", input_type=Int(optional=True), prefix="-q", doc=InputDocumentation(doc="Set the ASCII shift of the quality value(Q_SHIFT), default=64.\nNote: usually 64 or 33 for Illumina data.")), ToolInput(tag="in_set_output_kmers", input_type=File(optional=True), prefix="-m", doc=InputDocumentation(doc="Set whether to output kmers depth file, 1:yes, 0:no, default=1.\nNote: if you just want to get the distribution curve of kmer frequency, set '-m 0'.")), ToolInput(tag="in_set_total_number", input_type=Int(optional=True), prefix="-b", doc=InputDocumentation(doc="Set total bases number used to get kmers, default: all the bases of read files.\nNote: when sequencing depth is too much, you can set this option, about 30X\ndata bases is preferred.")), ToolInput(tag="in_set_output_prefix", input_type=String(optional=True), prefix="-p", doc=InputDocumentation(doc="Set the output prefix, default=output.\nNote: often use species name as prefix.")), ToolInput(tag="in_usage_kmerfreqar_readsfileslist", input_type=Int(), position=0, doc=InputDocumentation(doc="Usage:  KmerFreq_AR [OPTION] <reads_files_list>"))], outputs=[ToolOutput(tag="out_set_output_kmers", output_type=File(optional=True), selector=InputSelector(input_to_select="in_set_output_kmers", type_hint=File()), doc=OutputDocumentation(doc="Set whether to output kmers depth file, 1:yes, 0:no, default=1.\nNote: if you just want to get the distribution curve of kmer frequency, set '-m 0'."))], container=None, version="v0.1.0")


if __name__ == "__main__":
    # or "cwl"
    Kmerfreq_Ar_V0_1_0().translate("wdl", allow_empty_container=True)

